Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(482)

Unified Diff: remoting/host/win/host_service.cc

Issue 11040065: [Chromoting] Reimplemented the worker process launcher to take into account the encountered issues: (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Count the worker exiting too such as a failure. Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/host/win/host_service.cc
diff --git a/remoting/host/win/host_service.cc b/remoting/host/win/host_service.cc
index b882d52f413bccb5571ce8e08706be4eedbdeccc..d8ff0d16ef9d55f583e6d38123a7966234d30a66 100644
--- a/remoting/host/win/host_service.cc
+++ b/remoting/host/win/host_service.cc
@@ -39,7 +39,7 @@
#include "remoting/host/win/wts_console_observer.h"
#if !defined(REMOTING_MULTI_PROCESS)
-#include "remoting/host/win/wts_session_process_launcher.h"
+#include "remoting/host/win/wts_console_session_process_driver.h"
#endif // !defined(REMOTING_MULTI_PROCESS)
using base::StringPrintf;
@@ -213,8 +213,8 @@ void HostService::CreateLauncher(
#else // !defined(REMOTING_MULTI_PROCESS)
- // Create the session process launcher.
- child_.reset(new WtsSessionProcessLauncher(
+ // Create the console session process driver.
+ child_.reset(new WtsConsoleSessionProcessDriver(
base::Bind(&HostService::OnChildStopped, base::Unretained(this)),
this,
main_task_runner_,
@@ -249,7 +249,7 @@ int HostService::Elevate() {
CommandLine command_line(CommandLine::NO_PROGRAM);
command_line.CopySwitchesFrom(*CommandLine::ForCurrentProcess(),
kCopiedSwitchNames,
- _countof(kCopiedSwitchNames));
+ arraysize(kCopiedSwitchNames));
CommandLine::StringType parameters = command_line.GetCommandLineString();
// Launch the child process requesting elevation.

Powered by Google App Engine
This is Rietveld 408576698